import React, { useRef } from 'react'
import PropTypes from 'prop-types'
import { useIntersection } from 'react-use'
import Card from './card.jsx'
import CardFallback from './card-fallback.jsx'


const VirtualCard = ({
    fallback = false,
    ...props
}) => {
    const container = useRef(null)
    const intersection = useIntersection(container, { threshold: 0.1 })
    const hidden = intersection && intersection.intersectionRatio < 0.1
    const Component = fallback ? CardFallback : Card

    return (
        <Component
            ref={container}
            hidden={hidden}
            {...props}
        />
    )
}

VirtualCard.propTypes = {
    fallback: PropTypes.bool
}

export default VirtualCard